History
=======

v1.1.2 (2020-07-31)
---------------------

_improved release_          
the majority of reviewer comments have now been addressed.

v1.1.1 (2020-07-20)
---------------------

_improved release_          
added docker support, updated requirement files, added multi-platform CI testing, added Docker continuous build feature, fixed refs in text, added adnl refs, updated CONTRIBUTING.md, updated MAKEFILE, updated ORCID ids, removed docs/ folder.


v1.1.0 (2020-07-13)
---------------------

_improved release_          
starting to address JOSS reviewer comments. A lot of work still to be done.


v1.0.0 (2020-01-31)
---------------------

_initial release_           
basic functionality achieved.





